==> app_02_08_2024.zip: app/Http/Controllers/API/Auth/UserAPIController.php <==
<?php

namespace App\Http\Controllers\API\Auth;

use App\Http\Controllers\Controller;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Hash;
use Illuminate\Support\Str;
use Auth;
use Socialite;
use Validator;
use App\Models\User;
use Carbon\Carbon;
use Illuminate\Support\Facades\Cache;
use Symfony\Component\HttpFoundation\Response;

class UserAPIController extends Controller
{
    private $language;
    public function __construct()
    {
        // No need to call parent::__construct() here
        $this->language = request()->header('language-code') && request()->header('language-code') != '' ? request()->header('language-code') : 'en';
    }

    /**
     *  Do Signup
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    function doSignup(Request $request)
    {
        $validator = Validator::make($request->all(), [
            // 'name' => 'required',
            // 'email' => 'required|email|unique:users',
            'phone' => ['required', 'unique:users', 'regex:/^\+\d{1,3}\d{6,14}$/'],
            'password' => 'required|min:8',
            'confirm_password' => 'required|same:password',
            'profile_pic' => 'image|max:2048',
            'device_type' => 'required|in:web,app',
        ]);

        if ($validator->fails()) {
            return $this->sendError(__('lang.message_required_message'),$validator->errors());
        }

        $userData = [
            'type' => 'user', // Added equals sign
            'device_type' => $request->device_type, // Added equals sign
            'name' => $request->name,
            'email' => $request->email,
            'phone' => $request->phone, 
            'role_id' => '2',
            'token' => \Helpers::generateToken(),
            'status' => '1', // Corrected the variable to string
            'password' => Hash::make($request->confirm_password),
            'created_at' => date("Y-m-d H:i:s")
        ];

        if (isset($request['profile_pic']) && $request['profile_pic'] != '') {
            $uploadImage = \Helpers::uploadFiles($request['profile_pic'], 'user/profile_pic');
            if ($uploadImage['status'] == true) {
                $userData['image'] = $uploadImage['file_name']; // Changed 'image' to 'profile_pic'
            }
        }

        $user_id = User::insertGetId($userData); // Changed $user to $user_id

        if ($user_id) {
            $userData = User::where('id', $user_id)->first(); // Changed $user to $user_id
            if ($userData) {
                if ($userData->profile_pic != '') { // Changed 'image' to 'profile_pic'
                    $userData->profile_pic = url('uploads/user/profile_pic/' . $userData->profile_pic); // Changed 'image' to 'profile_pic'
                }
            }
            return $this->sendResponse($userData, __('lang.message_signup_success'));
        }
        return $this->sendError(__('lang.message_user_registered'));
    }

    /**
     *  Do Sign In
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    function doLogin(Request $request)
    {
        $validator = Validator::make($request->all(), [
            'email_phone' => 'required', // email or phone
            'password' => 'required',
        ]);

        if ($validator->fails()) {
            return $this->sendError(__('lang.message_required_message'), $validator->errors());
        }
        // Find user by email or phone
        $user = User::where(function($query) use ($request) {
                $query->where('email', $request->email_phone)
                      ->orWhere('phone', $request->email_phone);
            })
            ->where('type', 'user')
            ->where('id', '!=', 1)
            ->first();

        if (!$user) {
            return $this->sendError(__('lang.message_wrong_details'));
        }

        // Check if the password is correct
        if (!Hash::check($request->password, $user->password)) {
            return $this->sendError(__('lang.message_wrong_details'));
        }
        // Update the token
        $user->token = \Helpers::generateToken();
        $user->save();

        // Return user data with updated token
        $user->profile_pic = $user->profile_pic ? url('uploads/user/profile_pic/' . $user->profile_pic) : null;

        return $this->sendResponse($user, __('lang.message_login_success'));
    }
    
    /**
     *  Do Verify Email
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function doVerifyEmail(Request $request)
    {
        $validator = Validator::make($request->all(), [
            'email' => 'required|email|exists:users,email',
        ]);
        if ($validator->fails()) {
            return $this->sendError(__('lang.message_required_message'), $validator->errors());
        }
        $user = User::where('email', $request->email)->first();
        $url = "/api/change-password?userId={$user->id}";
        return $this->sendResponse($url, __('lang.message_signup_success'));
    }

    /**
     *  Do Change Password
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function doChangePassword(Request $request)
    {
        $validator = Validator::make($request->all(), [
            'password' => 'required|min:8',
            'confirm_password' => 'required|same:password',
        ]);

        if ($validator->fails()) {
            return $this->sendError(__('lang.message_required_message'), $validator->errors());
        }

        $user = User::find($request->userId);

        if (!$user) {
            return $this->sendError(__('lang.message_user_not_found'));
        }

        $user->password = Hash::make($request->password);
        $user->save();
        $login_url = "/api/login";
        return $this->sendResponse($login_url, __('lang.message_password_changes_success'));
    }

    /**
     *  Do Rediraction With Google
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function doRedirectToGoogle()
    {
        return Socialite::driver('google')->redirect();
    }

    /**
     *  Do Sign With Google
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function handleGoogleCallback()
    {
        try {
            $googleUser = Socialite::driver('google')->user();
            $user = User::where('email', $googleUser->email)->first();

            if ($user) {
                // User exists, update their token and other information
                $user->token = \Helpers::generateToken();
                $user->name = $googleUser->name;
                $user->profile_pic = $googleUser->avatar;
                $user->save();
            } else {
                // User does not exist, create a new user
                $user = User::create([
                    'type' => 'user',
                    'name' => $googleUser->name,
                    'email' => $googleUser->email,
                    'google_id' => $googleUser->id,
                    'profile_pic' => $googleUser->avatar,
                    'role_id' => '2',
                    'token' => \Helpers::generateToken(),
                    'status' => 'active',
                    'password' => Hash::make(uniqid()), // Generate a random password
                    'created_at' => now(),
                ]);
            }

            // Return user data with updated token
            $user->profile_pic = $user->profile_pic ? url('uploads/user/profile_pic/' . $user->profile_pic) : null;
            return $this->sendResponse($user, __('lang.message_signup_success'));

        } catch (\Exception $e) {
            // Log the error for debugging purposes
            \Log::error('Error during Google signup: ' . $e->getMessage());

            // Return an error response
            return response()->json(['error' => __('lang.message_google_signup_failed')], 500);
        }
    }



}

==> app_04_12_2024.zip: app/Http/Controllers/API/Auth/UserAPIController.php <==
<?php

namespace App\Http\Controllers\API\Auth;

use App\Http\Controllers\Controller;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Hash;
use Illuminate\Support\Str;
use Auth;
use Socialite;
use Validator;
use App\Models\User;
use App\Models\Vendor;
use Carbon\Carbon;
use Illuminate\Support\Facades\Cache;
use Symfony\Component\HttpFoundation\Response;

class UserAPIController extends Controller
{
    private $language;
    public function __construct()
    {
        // No need to call parent::__construct() here
        $this->language = request()->header('language-code') && request()->header('language-code') != '' ? request()->header('language-code') : 'en';
    }

    /**
     *  Do Signup
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    function doSignup(Request $request)
    {
        $validator = Validator::make($request->all(), [
            // 'name' => 'required',
            // 'email' => 'required|email|unique:users',
            'phone' => ['required', 'unique:users', 'regex:/^\+\d{1,3}\d{6,14}$/'],
            'password' => 'required|min:8',
            'confirm_password' => 'required|same:password',
            'profile_pic' => 'image|max:2048',
            'device_type' => 'required|in:web,app',
        ]);

        if ($validator->fails()) {
            return $this->sendError(__('lang.message_required_message'),$validator->errors());
        }

        $userData = [
            'type' => 'user', // Added equals sign
            'device_type' => $request->device_type, // Added equals sign
            'name' => $request->name,
            'email' => $request->email,
            'phone' => $request->phone, 
            'role_id' => '2',
            'token' => \Helpers::generateToken(),
            'status' => '1', // Corrected the variable to string
            'password' => Hash::make($request->confirm_password),
            'created_at' => date("Y-m-d H:i:s")
        ];

        if (isset($request['profile_pic']) && $request['profile_pic'] != '') {
            $uploadImage = \Helpers::uploadFiles($request['profile_pic'], 'user/profile_pic');
            if ($uploadImage['status'] == true) {
                $userData['image'] = $uploadImage['file_name']; // Changed 'image' to 'profile_pic'
            }
        }

        $user_id = User::insertGetId($userData); // Changed $user to $user_id

        if ($user_id) {
            $userData = User::where('id', $user_id)->first(); // Changed $user to $user_id
            if ($userData) {
                if ($userData->profile_pic != '') { // Changed 'image' to 'profile_pic'
                    $userData->profile_pic = url('uploads/user/profile_pic/' . $userData->profile_pic); // Changed 'image' to 'profile_pic'
                }
            }
            return $this->sendResponse($userData, __('lang.message_signup_success'));
        }
        return $this->sendError(__('lang.message_user_registered'));
    }

    /**
     *  Do Sign In
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    function doLogin(Request $request)
    {
        $validator = Validator::make($request->all(), [
            'email_phone' => 'required', // email or phone
            'password' => 'required',
        ]);

        if ($validator->fails()) {
            return $this->sendError(__('lang.message_required_message'), $validator->errors());
        }
        // Find user by email or phone
        $user = User::where(function($query) use ($request) {
                $query->where('email', $request->email_phone)
                      ->orWhere('phone', $request->email_phone);
            })
            ->where('type', 'user')
            ->where('id', '!=', 1)
            ->first();

        if (!$user) {
            return $this->sendError(__('lang.message_wrong_details'));
        }

        // Check if the password is correct
        if (!Hash::check($request->password, $user->password)) {
            return $this->sendError(__('lang.message_wrong_details'));
        }
        // Update the token
        $user->token = \Helpers::generateToken();
        $user->save();

        // Return user data with updated token
        $user->profile_pic = $user->profile_pic ? url('uploads/user/profile_pic/' . $user->profile_pic) : null;

        return $this->sendResponse($user, __('lang.message_login_success'));
    }
    
    /**
     *  Do Verify Email
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function doVerifyEmail(Request $request)
    {
        $validator = Validator::make($request->all(), [
            'email' => 'required|email|exists:users,email',
        ]);
        if ($validator->fails()) {
            return $this->sendError(__('lang.message_required_message'), $validator->errors());
        }
        $user = User::where('email', $request->email)->first();
        $url = "/api/change-password?userId={$user->id}";
        return $this->sendResponse($url, __('lang.message_signup_success'));
    }

    /**
     *  Do Change Password
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function doChangePassword(Request $request)
    {
        $validator = Validator::make($request->all(), [
            'password' => 'required|min:8',
            'confirm_password' => 'required|same:password',
        ]);

        if ($validator->fails()) {
            return $this->sendError(__('lang.message_required_message'), $validator->errors());
        }

        $user = User::find($request->userId);

        if (!$user) {
            return $this->sendError(__('lang.message_user_not_found'));
        }

        $user->password = Hash::make($request->password);
        $user->save();
        $login_url = "/api/login";
        return $this->sendResponse($login_url, __('lang.message_password_changes_success'));
    }

    /**
     *  Do Rediraction With Google
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function doRedirectToGoogle()
    {
        return Socialite::driver('google')->redirect();
    }

    /**
     *  Do Sign With Google
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function handleGoogleCallback()
    {
        try {
            $googleUser = Socialite::driver('google')->user();
            $user = User::where('email', $googleUser->email)->first();

            if ($user) {
                // User exists, update their token and other information
                $user->token = \Helpers::generateToken();
                $user->name = $googleUser->name;
                $user->profile_pic = $googleUser->avatar;
                $user->save();
            } else {
                // User does not exist, create a new user
                $user = User::create([
                    'type' => 'user',
                    'name' => $googleUser->name,
                    'email' => $googleUser->email,
                    'google_id' => $googleUser->id,
                    'profile_pic' => $googleUser->avatar,
                    'role_id' => '2',
                    'token' => \Helpers::generateToken(),
                    'status' => 'active',
                    'password' => Hash::make(uniqid()), // Generate a random password
                    'created_at' => now(),
                ]);
            }

            // Return user data with updated token
            $user->profile_pic = $user->profile_pic ? url('uploads/user/profile_pic/' . $user->profile_pic) : null;
            return $this->sendResponse($user, __('lang.message_signup_success'));

        } catch (\Exception $e) {
            // Log the error for debugging purposes
            \Log::error('Error during Google signup: ' . $e->getMessage());

            // Return an error response
            return response()->json(['error' => __('lang.message_google_signup_failed')], 500);
        }
    }
    
    //become a host api
  function becomeHost(Request $request)
{
    // Validate the request data
    $validator = Validator::make($request->all(), [
        'userId' => 'required',
    ]);

    if ($validator->fails()) {
        return $this->sendError('User ID is required.', $validator->errors());
    }

    // Find user by userId
    $user = User::where('id', $request->userId)
        ->where('type', 'user') // Ensure the user is not already a vendor
        ->where('id', '!=', 1)  // Exclude admin or super admin with id = 1
        ->first();

    if (!$user) {
        return $this->sendError('User not found.');
    }

    // Prepare user data for insertion into the vendors table
    $vendorData = [
        'name'              => $user->name,
        'email'             => $user->email,
        'type'              => "vendor",
        'password'          => $user->password,
        'phone'             => $user->phone,
        'adharcard_image'   => $user->adharcard_image,
        'image'             => $user->image,
        'token'             => $user->token,
        'device_type'       => $user->device_type,
        'status'            => $user->status,
        'is_verified'       => $user->is_verified,
        'enable_notification' => $user->enable_notification,
        'otp'               => $user->otp,
        'role_id'           => $user->role_id,
        'remember_token'    => $user->remember_token,
        'email_verified_at' => $user->email_verified_at,
        'created_at'        => $user->created_at,
        'updated_at'        => $user->updated_at,
        'deleted_at'        => $user->deleted_at,
    ];

    Vendor::create($vendorData);

    $user->forceDelete();

    return $this->sendResponse($vendorData, 'You are now a host.');
}
  



}
